Module io

Module io 

Variable loading from BIDS datasets.

Reads variables from all standard BIDS tabular files (participants.tsv, sessions.tsv, scans.tsv, events.tsv, physio/stim .tsv.gz, regressors.tsv) and organizes them into a NodeIndex hierarchy.

The load_variables() function is the main entry point, accepting a BidsLayout, optional variable type filters, and an optional level filter.

Enums

VariableType
The types of variables that can be loaded.

Functions

load_variables
Load variables from a BIDS dataset.