Module variables

Module variables 

BIDS variable types: simple, sparse-run, and dense-run.

Implements the three variable types used in BIDS statistical modeling: SimpleVariable (participant/session-level), SparseRunVariable (event-level with onset/duration), and DenseRunVariable (continuous regressors sampled at TR).

Structs

DenseRunVariable
A dense run variable with uniformly-sampled time series data.
SimpleVariable
A simple variable with no timing information.
SparseRunVariable
A sparse run variable representing events with onset, duration, and amplitude.

Functions

apply_grouped
Apply a function to groups defined by a grouper.
get_grouper
Get a grouper key for groupby operations.
merge_simple
Merge a list of simple variables with the same name.
merge_sparse
Merge sparse run variables.