SparseRunVariable

Struct SparseRunVariable 

pub struct SparseRunVariable {
    pub name: String,
    pub source: String,
    pub onset: Vec<f64>,
    pub duration: Vec<f64>,
    pub amplitude: Vec<f64>,
    pub str_amplitude: Vec<String>,
    pub index: Vec<StringEntities>,
    pub entities: StringEntities,
    pub run_info: Vec<RunInfo>,
}
A sparse run variable representing events with onset, duration, and amplitude.

Loaded from _events.tsv files, each event has a time point (onset), a duration, and an amplitude value. Multiple runs can be represented in a single variable via the run_info vector.

Can be converted to a DenseRunVariable via to_dense() for convolution with hemodynamic response functions or other time-domain operations.

Corresponds to PyBIDS’ SparseRunVariable class.

Fields

name: Stringsource: Stringonset: Vec<f64>duration: Vec<f64>amplitude: Vec<f64>str_amplitude: Vec<String>index: Vec<StringEntities>entities: StringEntitiesrun_info: Vec<RunInfo>

Implementations

Source

impl SparseRunVariable

pub fn new( name: &str, source: &str, onset: Vec<f64>, duration: Vec<f64>, amplitude: Vec<String>, index: Vec<StringEntities>, run_info: Vec<RunInfo>, ) -> Self

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn get_duration(&self) -> f64

Total duration of all runs.

pub fn to_dense(&self, sampling_rate: Option<f64>) -> DenseRunVariable

Convert sparse to dense representation using GCD-based bin size.

pub fn filter(&self, filters: &StringEntities) -> Self

Filter events by entity criteria.

pub fn to_rows(&self) -> Vec<StringEntities>

Convert to tabular rows.

Source

impl SparseRunVariable

pub fn select_rows(&self, indices: &[usize]) -> Self

Select specific row indices.

pub fn split(&self, group_col: &str) -> Vec<Self>

Split into multiple variables based on a grouper.